/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.core.container.mojo;

import java.util.Locale;
import java.util.ResourceBundle;
import java.text.MessageFormat;

class AbstractSourceMojoBundle
{

  private static final AbstractSourceMojoBundle instance =
    new AbstractSourceMojoBundle();

  AbstractSourceMojoBundle()
  {
    this.getMessage ( "sourceNotFound", Locale.getDefault() );
    this.getMessage ( "cannotReadOrWriteFile", Locale.getDefault() );
    this.getMessage ( "fileInfo", Locale.getDefault() );
    this.getMessage ( "skippingProject", Locale.getDefault() );
  }

  static AbstractSourceMojoBundle getInstance()
  {
    return instance;
  }

  String getSourceNotFoundText ( final Locale locale )
  {
    return this.getMessage ( "sourceNotFound", locale );
  }

  MessageFormat getSourceNotFoundMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "sourceNotFound", locale ), locale );
  }
  String getCannotReadOrWriteFileText ( final Locale locale )
  {
    return this.getMessage ( "cannotReadOrWriteFile", locale );
  }

  MessageFormat getCannotReadOrWriteFileMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "cannotReadOrWriteFile", locale ), locale );
  }
  String getFileInfoText ( final Locale locale )
  {
    return this.getMessage ( "fileInfo", locale );
  }

  MessageFormat getFileInfoMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "fileInfo", locale ), locale );
  }
  String getSkippingProjectText ( final Locale locale )
  {
    return this.getMessage ( "skippingProject", locale );
  }

  MessageFormat getSkippingProjectMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "skippingProject", locale ), locale );
  }
  private String getMessage( final String key, Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return ResourceBundle.getBundle( "org/jdtaus/core/container/mojo/AbstractSourceMojo",
                                     locale ).getString( key );

  }
}
