/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.core.container.mojo;

import java.util.Locale;
import java.util.ResourceBundle;
import java.text.MessageFormat;

class ContainerMojoBundle
{

  private static final ContainerMojoBundle instance =
    new ContainerMojoBundle();

  ContainerMojoBundle()
  {
    this.getMessage ( "unexpectedEndOfInput", Locale.getDefault() );
    this.getMessage ( "constructorComment", Locale.getDefault() );
    this.getMessage ( "dependencyGetter", Locale.getDefault() );
    this.getMessage ( "closingFoldingMarkerNetbeans", Locale.getDefault() );
    this.getMessage ( "dependencyConstructorComment", Locale.getDefault() );
    this.getMessage ( "propertyGetterComment", Locale.getDefault() );
    this.getMessage ( "missingMarkers", Locale.getDefault() );
    this.getMessage ( "processingModule", Locale.getDefault() );
    this.getMessage ( "skippingTestModule", Locale.getDefault() );
    this.getMessage ( "finalModifierMismatch", Locale.getDefault() );
    this.getMessage ( "propertyInitializerComment", Locale.getDefault() );
    this.getMessage ( "generatorWarning", Locale.getDefault() );
    this.getMessage ( "skippingMainModule", Locale.getDefault() );
    this.getMessage ( "openingFoldingMarkerNetbeans", Locale.getDefault() );
    this.getMessage ( "specificationMetaDataComment", Locale.getDefault() );
    this.getMessage ( "implementationMetaDataComment", Locale.getDefault() );
  }

  static ContainerMojoBundle getInstance()
  {
    return instance;
  }

  String getUnexpectedEndOfInputText ( final Locale locale )
  {
    return this.getMessage ( "unexpectedEndOfInput", locale );
  }

  MessageFormat getUnexpectedEndOfInputMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "unexpectedEndOfInput", locale ), locale );
  }
  String getConstructorCommentText ( final Locale locale )
  {
    return this.getMessage ( "constructorComment", locale );
  }

  MessageFormat getConstructorCommentMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "constructorComment", locale ), locale );
  }
  String getDependencyGetterText ( final Locale locale )
  {
    return this.getMessage ( "dependencyGetter", locale );
  }

  MessageFormat getDependencyGetterMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "dependencyGetter", locale ), locale );
  }
  String getClosingFoldingMarkerNetbeansText ( final Locale locale )
  {
    return this.getMessage ( "closingFoldingMarkerNetbeans", locale );
  }

  MessageFormat getClosingFoldingMarkerNetbeansMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "closingFoldingMarkerNetbeans", locale ), locale );
  }
  String getDependencyConstructorCommentText ( final Locale locale )
  {
    return this.getMessage ( "dependencyConstructorComment", locale );
  }

  MessageFormat getDependencyConstructorCommentMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "dependencyConstructorComment", locale ), locale );
  }
  String getPropertyGetterCommentText ( final Locale locale )
  {
    return this.getMessage ( "propertyGetterComment", locale );
  }

  MessageFormat getPropertyGetterCommentMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "propertyGetterComment", locale ), locale );
  }
  String getMissingMarkersText ( final Locale locale )
  {
    return this.getMessage ( "missingMarkers", locale );
  }

  MessageFormat getMissingMarkersMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "missingMarkers", locale ), locale );
  }
  String getProcessingModuleText ( final Locale locale )
  {
    return this.getMessage ( "processingModule", locale );
  }

  MessageFormat getProcessingModuleMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "processingModule", locale ), locale );
  }
  String getSkippingTestModuleText ( final Locale locale )
  {
    return this.getMessage ( "skippingTestModule", locale );
  }

  MessageFormat getSkippingTestModuleMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "skippingTestModule", locale ), locale );
  }
  String getFinalModifierMismatchText ( final Locale locale )
  {
    return this.getMessage ( "finalModifierMismatch", locale );
  }

  MessageFormat getFinalModifierMismatchMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "finalModifierMismatch", locale ), locale );
  }
  String getPropertyInitializerCommentText ( final Locale locale )
  {
    return this.getMessage ( "propertyInitializerComment", locale );
  }

  MessageFormat getPropertyInitializerCommentMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "propertyInitializerComment", locale ), locale );
  }
  String getGeneratorWarningText ( final Locale locale )
  {
    return this.getMessage ( "generatorWarning", locale );
  }

  MessageFormat getGeneratorWarningMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "generatorWarning", locale ), locale );
  }
  String getSkippingMainModuleText ( final Locale locale )
  {
    return this.getMessage ( "skippingMainModule", locale );
  }

  MessageFormat getSkippingMainModuleMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "skippingMainModule", locale ), locale );
  }
  String getOpeningFoldingMarkerNetbeansText ( final Locale locale )
  {
    return this.getMessage ( "openingFoldingMarkerNetbeans", locale );
  }

  MessageFormat getOpeningFoldingMarkerNetbeansMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "openingFoldingMarkerNetbeans", locale ), locale );
  }
  String getSpecificationMetaDataCommentText ( final Locale locale )
  {
    return this.getMessage ( "specificationMetaDataComment", locale );
  }

  MessageFormat getSpecificationMetaDataCommentMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "specificationMetaDataComment", locale ), locale );
  }
  String getImplementationMetaDataCommentText ( final Locale locale )
  {
    return this.getMessage ( "implementationMetaDataComment", locale );
  }

  MessageFormat getImplementationMetaDataCommentMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "implementationMetaDataComment", locale ), locale );
  }
  private String getMessage( final String key, Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return ResourceBundle.getBundle( "org/jdtaus/core/container/mojo/ContainerMojo",
                                     locale ).getString( key );

  }
}
