/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.core.container.mojo;

import java.util.Locale;
import java.util.ResourceBundle;
import java.text.MessageFormat;

class VerifyModelMojoBundle
{

  private static final VerifyModelMojoBundle instance =
    new VerifyModelMojoBundle();

  VerifyModelMojoBundle()
  {
    this.getMessage ( "finalModifierMismatch", Locale.getDefault() );
    this.getMessage ( "missingImplementation", Locale.getDefault() );
    this.getMessage ( "missingImplementedSpecification", Locale.getDefault() );
    this.getMessage ( "missingInterface", Locale.getDefault() );
    this.getMessage ( "classNotFound", Locale.getDefault() );
  }

  static VerifyModelMojoBundle getInstance()
  {
    return instance;
  }

  String getFinalModifierMismatchText ( final Locale locale )
  {
    return this.getMessage ( "finalModifierMismatch", locale );
  }

  MessageFormat getFinalModifierMismatchMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "finalModifierMismatch", locale ), locale );
  }
  String getMissingImplementationText ( final Locale locale )
  {
    return this.getMessage ( "missingImplementation", locale );
  }

  MessageFormat getMissingImplementationMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "missingImplementation", locale ), locale );
  }
  String getMissingImplementedSpecificationText ( final Locale locale )
  {
    return this.getMessage ( "missingImplementedSpecification", locale );
  }

  MessageFormat getMissingImplementedSpecificationMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "missingImplementedSpecification", locale ), locale );
  }
  String getMissingInterfaceText ( final Locale locale )
  {
    return this.getMessage ( "missingInterface", locale );
  }

  MessageFormat getMissingInterfaceMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "missingInterface", locale ), locale );
  }
  String getClassNotFoundText ( final Locale locale )
  {
    return this.getMessage ( "classNotFound", locale );
  }

  MessageFormat getClassNotFoundMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "classNotFound", locale ), locale );
  }
  private String getMessage( final String key, Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return ResourceBundle.getBundle( "org/jdtaus/core/container/mojo/VerifyModelMojo",
                                     locale ).getString( key );

  }
}
